package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````$"D```````!``````````'C!````
M`````````$``.``.`$``'P`>``8````$````0`````````!``````````$``
M````````$`,````````0`P````````@``````````P````0```"D`P``````
M`*0#````````I`,````````<`````````!P``````````0`````````!````
M!`````````````````````````````````````@:````````"!H`````````
M$`````````$````%`````"``````````(``````````@````````W4H`````
M``#=2@`````````0`````````0````0`````<`````````!P`````````'``
M``````"D1P```````*1'`````````!`````````!````!@```+"[````````
ML,L```````"PRP```````'@$````````H`0`````````$`````````(````&
M````V+L```````#8RP```````-C+``````````(``````````@````````@`
M````````!`````0```!0`P```````%`#````````4`,````````P````````
M`#``````````"``````````$````!````(`#````````@`,```````"``P``
M`````"0`````````)``````````$``````````0````$````F+8```````"8
MM@```````)BV````````#`$````````,`0````````0`````````4^5T9`0`
M``!0`P```````%`#````````4`,````````P`````````#``````````"```
M``````!0Y71D!````+"P````````L+````````"PL`````````0!````````
M!`$````````$`````````%'E=&0&````````````````````````````````
M`````````````````````````!``````````4N5T9`0```"PNP```````+#+
M````````L,L```````!0!````````%`$`````````0`````````$````(```
M``4```!'3E4``@``P`0````#``````````*``,`$`````0`````````$````
M%`````,```!'3E4`C[#\1;T(2!8MCB6M#=@)8Z&M@^`O;&EB-C0O;&0M;&EN
M=7@M>#@V+38T+G-O+C(`$0```$,````$````"````"`0$``%0`2$*`(`!("&
M`(2"B0`""2`$"(B`$4&Z``((`````$,```!&````20```$H```!2````4P``
M`%0`````````5@```%<```!8````60```%L```!=``````````````!NQ=\?
MSMY'+6M_FGPNQ9NVU&34?"'_Y`[9<5@<XD?&`;(!BV^L2^/`0OK7A\+E/RRZ
MXY)\^J%L8)E/PYMK"4/69Z_,9D)%U>R)!W#3,V+;[16,)<P-.I<+?JF<F]%E
MSFW@IP(*:QJ>4*/@^TD```````````````````````````````"F`@``$@``
M```````````````````````-`@``$@````````````````````````",````
M$0````````````````````````"-`@``$@`````````````````````````O
M`0``$@````````````````````````#H`0``$@``````````````````````
M``!)`@``$@`````````````````````````!````(```````````````````
M``````"P`0``$@````````````````````````!G````$@``````````````
M``````````"]`0``$@````````````````````````"4````$@``````````
M``````````````"&`@``$@````````````````````````#8`@``$@``````
M``````````````````#]`0``$@````````````````````````##````$@``
M``````````````````````#3````$@`````````````````````````A`0``
M$@````````````````````````!B`0``$@````````````````````````!;
M`0``$@````````````````````````"*````$0``````````````````````
M``""`P``$@`````````````````````````0````(```````````````````
M``````"^`@``$@````````````````````````"K`@``$@``````````````
M``````````"N````$@`````````````````````````L````(```````````
M``````````````#*`0``$@````````````````````````"<````$@``````
M``````````````````"A`0``$@````````````````````````"P`@``$@``
M``````````````````````#9````%@````````````````````````#L````
M$@````````````````````````!<`@``$@`````````````````````````'
M`0``$@````````````````````````#)`@``$@``````````````````````
M``"2`0``$@````````````````````````#V`0``$@``````````````````
M```````V`0``$@`````````````````````````8`0``$@``````````````
M``````````!O`0``$@````````````````````````"8`@``$@``````````
M``````````````#7`0``$@````````````````````````!V`0``$@``````
M```````````````````9`@``$@````````````````````````!Y````$@``
M``````````````````````"$`0``$@````````````````````````!]`0``
M$@````````````````````````#)`0``$@````````````````````````#"
M`0``$@`````````````````````````E`@``$@``````````````````````
M``!Z`@``$@````````````````````````"U`0``$@``````````````````
M``````#*````$@````````````````````````"U````$@``````````````
M``````````":`0``$0````````````````````````!M`@``$0``````````
M``````````````"+`0``$@````````````````````````!3`0``$@``````
M``````````````````#\````$@````````````````````````!%`0``$@``
M```````````````````````Z`@``$@````````````````````````!&````
M$@````````````````````````#A`@``$@````````````````````````"D
M````$@````````````````````````#1`0``$@``````````````````````
M``"+`P``$@`/`.!D````````%P$```````#@`P``$@`/`!!7````````;0H`
M``````!3````$@`/```G````````#@(````````"`P``$@`/`&!+````````
M"0`````````@`P``$@`/`(!A````````6@,````````&!```$@`/`'!+````
M````M@(```````#&`P``$``<`"C0```````````````````3`P``$@`/`#!.
M````````,@`````````V`P``$@`/``!3````````R`````````"7`P``$0`1
M``!P````````!`````````"S`P``$@`/`%!F````````X`$```````"^`P``
M$@`/`%!*````````*0````````#;`P``$``<`%#0``````````````````#T
M`P``$@`/``!6````````"`$````````=!```$@`/`-!3````````P```````
M``"F`P``$``;``#0``````````````````!:`P``$@`/`'!.````````00$`
M``````#M`P``$``;`"C0```````````````````3!```$0`;`"#0````````
M"`````````"L`P``$@`/`!`I````````)@````````#2`P``$@`/``!F````
M````1@````````"H`P``(``;``#0``````````````````!P`P``$@`/`.!5
M````````'@````````!8````(@````````````````````````!$`P``$@`/
M`(!*````````W0````````!F`P``$@`/`#!H````````@P(````````E!```
M$@`/`,!/````````/@,`````````7U]G;6]N7W-T87)T7U\`7TE435]D97)E
M9VES=&5R5$U#;&]N951A8FQE`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`
M7U]L:6)C7W-T87)T7VUA:6X`7U]C>&%?9FEN86QI>F4`7U]R96=I<W1E<E]A
M=&9O<FL`7U]S=&%C:U]C:&M?9F%I;`!?7V5N=FER;VX`<W1R;F-M<`!O<&5N
M9&ER`')E861D:7(V-`!S=')L96X`7U]S<')I;G1F7V-H:P!U;FQI;FL`8VQO
M<V5D:7(`<FUD:7(`4$Q?8W5R<F5N=%]C;VYT97AT`&)O;W1?1'EN84QO861E
M<@!097)L7VYE=UA3`%!E<FQ?;F5W6%-?9FQA9W,`<F5A9&QI;FL`4&5R;%]S
M=E]S971P=@!M96UC:'(`4&5R;%]S=E]S971P=FX`7U]M96UM;W9E7V-H:P!R
M96%L;&]C`&=E='!I9`!?7VUE;6-P>5]C:&L`<W1R8VAR`'-T<F1U<`!S=')T
M;VL`<W1R8VUP`&%C8V5S<P!S=')R8VAR`'-T9&5R<@!?7W9F<')I;G1F7V-H
M:P!E>&ET`&QS965K-C0`<F5A9`!G971U:60`;'-T870V-`!M:V1I<@!?7V5R
M<FYO7VQO8V%T:6]N`%]?9G!R:6YT9E]C:&L`;W!E;C8T`%!E<FQ?9W9?9F5T
M8VAP=@!097)L7V=E=%]S=@!097)L7VUG7W-E=`!097)L7V-R;V%K7VYO8V]N
M=&5X=`!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]A
M=&9O<FM?;&]C:P!03%]D;U]U;F1U;7``4&5R;%]S869E<WES;6%L;&]C`'!E
M<FQ?<&%R<V4`<&5R;%]D97-T<G5C=`!P97)L7V9R964`4&5R;%]S>7-?=&5R
M;0!P97)L7V%L;&]C`'!E<FQ?8V]N<W1R=6-T`'!E<FQ?<G5N`&UE;6-P>0!L
M:6)P97)L+G-O+C4N-#``;&EB8RYS;RXV`'!A<E]C=7)R96YT7V5X96,`<&%R
M7V)A<V5N86UE`%A37TEN=&5R;F%L<U]005)?0D]/5`!P87)?96YV7V-L96%N
M`'!A<E]C=7)R96YT7V5X96-?<')O8P!P87)?9&ER;F%M90!S:&%?9FEN86P`
M9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``7TE/7W-T
M9&EN7W5S960`7U]D871A7W-T87)T`'-H85]U<&1A=&4`>'-?:6YI=`!?7V)S
M<U]S=&%R=`!S:&%?:6YI=`!?96YD`'!A<E]M:W1M<&1I<@!?961A=&$`<&%R
M7W-E='5P7VQI8G!A=&@`<&%R7V9I;F1P<F]G`&UY7W!A<E]P;`!P87)?9&EE
M`'!A<E]I;FET7V5N=@!'3$E"0U\R+C$T`$=,24)#7S(N,S0`1TQ)0D-?,BXT
M`$=,24)#7S(N,S,`1TQ)0D-?,BXS+C(`1TQ)0D-?,BXS+C0`1TQ)0D-?,BXR
M+C4``````0`!``(``0`"``,``0`!``(`!``"``(``@`!``$``@`"``$``P`"
M``(``@`!``$``@`"``$`!0`"``,``0`!``$``0`!``$``@`"``$``@`"``$`
M`@`"``$`!@`"``(`!0`"``$``0`"``(``P`"``$``@`"``$``P`!``<`"``"
M``(``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``(``0`!``$````!``<`^`(``!``````````E)&6!@``"``R!```$```
M`+21E@8```<`/00``!`````4:6D-```&`$@$```0````LY&6!@``!0!2!```
M$````'(9:0D```0`700``!````!T&6D)```#`&D$```0````=1II"0```@!U
M!````````+#+````````"`````````#P*0```````+C+````````"```````
M``"P*0```````,#+````````"`````````!3<0```````,C+````````"```
M``````".<````````-#+````````"`````````"@<`````````C0````````
M"``````````(T````````"#0````````"`````````#X<@```````*#/````
M````!@````,``````````````*C/````````!@````<``````````````+#/
M````````!@````@``````````````+C/````````!@```!<`````````````
M`,#/````````!@```!L``````````````,C/````````!@```%H`````````
M`````-#/````````$@```"```````````````-C/````````!@```"$`````
M`````````.#/````````!@```"(``````````````.C/````````!@```#@`
M`````````````/#/````````!@```#D``````````````/C/````````!@``
M`#\``````````````/#-````````!P````$``````````````/C-````````
M!P````(```````````````#.````````!P````0```````````````C.````
M````!P````4``````````````!#.````````!P````8``````````````!C.
M````````!P````D``````````````"#.````````!P````H`````````````
M`"C.````````!P````L``````````````##.````````!P````P`````````
M`````#C.````````!P````T``````````````$#.````````!P````X`````
M`````````$C.````````!P````\``````````````%#.````````!P```!``
M`````````````%C.````````!P```!$``````````````&#.````````!P``
M`!(``````````````&C.````````!P```!,``````````````'#.````````
M!P```!0``````````````'C.````````!P```!8``````````````(#.````
M````!P```!@``````````````(C.````````!P```!D``````````````)#.
M````````!P```!H``````````````)C.````````!P```!P`````````````
M`*#.````````!P```!T``````````````*C.````````!P```!X`````````
M`````+#.````````!P```!\``````````````+C.````````!P```",`````
M`````````,#.````````!P```"0``````````````,C.````````!P```"4`
M`````````````-#.````````!P```"8``````````````-C.````````!P``
M`"<``````````````.#.````````!P```"@``````````````.C.````````
M!P```"D``````````````/#.````````!P```"H``````````````/C.````
M````!P```"L```````````````#/````````!P```"P```````````````C/
M````````!P```"T``````````````!#/````````!P```"X`````````````
M`!C/````````!P```"\``````````````"#/````````!P```#``````````
M`````"C/````````!P```#$``````````````##/````````!P```#(`````
M`````````#C/````````!P```#,``````````````$#/````````!P```#0`
M`````````````$C/````````!P```#4``````````````%#/````````!P``
M`#8``````````````%C/````````!P```#<``````````````&#/````````
M!P```#H``````````````&C/````````!P```#L``````````````'#/````
M````!P```#P``````````````'C/````````!P```#T``````````````(#/
M````````!P```#X``````````````(C/````````!P```$``````````````
M`)#/````````!P```$$``````````````)C/````````!P```$(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#S#Q[Z2(/L"$B+!:&O``!(A<!T`O_02(/$",,``````/\UNJT``/\EO*T`
M``\?0`#S#Q[Z:`````#IXO___V:0\P\>^F@!````Z=+___]FD/,/'OIH`@``
M`.G"____9I#S#Q[Z:`,```#ILO___V:0\P\>^F@$````Z:+___]FD/,/'OIH
M!0```.F2____9I#S#Q[Z:`8```#I@O___V:0\P\>^F@'````Z7+___]FD/,/
M'OIH"````.EB____9I#S#Q[Z:`D```#I4O___V:0\P\>^F@*````Z4+___]F
MD/,/'OIH"P```.DR____9I#S#Q[Z:`P```#I(O___V:0\P\>^F@-````Z1+_
M__]FD/,/'OIH#@```.D"____9I#S#Q[Z:`\```#I\O[__V:0\P\>^F@0````
MZ>+^__]FD/,/'OIH$0```.G2_O__9I#S#Q[Z:!(```#IPO[__V:0\P\>^F@3
M````Z;+^__]FD/,/'OIH%````.FB_O__9I#S#Q[Z:!4```#IDO[__V:0\P\>
M^F@6````Z8+^__]FD/,/'OIH%P```.ER_O__9I#S#Q[Z:!@```#I8O[__V:0
M\P\>^F@9````Z5+^__]FD/,/'OIH&@```.E"_O__9I#S#Q[Z:!L```#I,O[_
M_V:0\P\>^F@<````Z2+^__]FD/,/'OIH'0```.D2_O__9I#S#Q[Z:!X```#I
M`O[__V:0\P\>^F@?````Z?+]__]FD/,/'OIH(````.GB_?__9I#S#Q[Z:"$`
M``#ITOW__V:0\P\>^F@B````Z<+]__]FD/,/'OIH(P```.FR_?__9I#S#Q[Z
M:"0```#IHOW__V:0\P\>^F@E````Z9+]__]FD/,/'OIH)@```.F"_?__9I#S
M#Q[Z:"<```#I<OW__V:0\P\>^F@H````Z6+]__]FD/,/'OIH*0```.E2_?__
M9I#S#Q[Z:"H```#I0OW__V:0\P\>^F@K````Z3+]__]FD/,/'OIH+````.DB
M_?__9I#S#Q[Z:"T```#I$OW__V:0\P\>^F@N````Z0+]__]FD/,/'OIH+P``
M`.GR_/__9I#S#Q[Z:#````#IXOS__V:0\P\>^F@Q````Z=+\__]FD/,/'OIH
M,@```.G"_/__9I#S#Q[Z:#,```#ILOS__V:0\P\>^F@T````Z:+\__]FD/,/
M'OIH-0```.F2_/__9I#S#Q[Z_R4NK```9@\?1```\P\>^O\E1JH``&8/'T0`
M`/,/'OK_)3ZJ``!F#Q]$``#S#Q[Z_R4VJ@``9@\?1```\P\>^O\E+JH``&8/
M'T0``/,/'OK_)2:J``!F#Q]$``#S#Q[Z_R4>J@``9@\?1```\P\>^O\E%JH`
M`&8/'T0``/,/'OK_)0ZJ``!F#Q]$``#S#Q[Z_R4&J@``9@\?1```\P\>^O\E
M_JD``&8/'T0``/,/'OK_)?:I``!F#Q]$``#S#Q[Z_R7NJ0``9@\?1```\P\>
M^O\EYJD``&8/'T0``/,/'OK_)=ZI``!F#Q]$``#S#Q[Z_R76J0``9@\?1```
M\P\>^O\ESJD``&8/'T0``/,/'OK_)<:I``!F#Q]$``#S#Q[Z_R6^J0``9@\?
M1```\P\>^O\EMJD``&8/'T0``/,/'OK_):ZI``!F#Q]$``#S#Q[Z_R6FJ0``
M9@\?1```\P\>^O\EGJD``&8/'T0``/,/'OK_)9:I``!F#Q]$``#S#Q[Z_R6.
MJ0``9@\?1```\P\>^O\EAJD``&8/'T0``/,/'OK_)7ZI``!F#Q]$``#S#Q[Z
M_R5VJ0``9@\?1```\P\>^O\E;JD``&8/'T0``/,/'OK_)6:I``!F#Q]$``#S
M#Q[Z_R5>J0``9@\?1```\P\>^O\E5JD``&8/'T0``/,/'OK_)4ZI``!F#Q]$
M``#S#Q[Z_R5&J0``9@\?1```\P\>^O\E/JD``&8/'T0``/,/'OK_)3:I``!F
M#Q]$``#S#Q[Z_R4NJ0``9@\?1```\P\>^O\E)JD``&8/'T0``/,/'OK_)1ZI
M``!F#Q]$``#S#Q[Z_R46J0``9@\?1```\P\>^O\E#JD``&8/'T0``/,/'OK_
M)0:I``!F#Q]$``#S#Q[Z_R7^J```9@\?1```\P\>^O\E]J@``&8/'T0``/,/
M'OK_)>ZH``!F#Q]$``#S#Q[Z_R7FJ```9@\?1```\P\>^O\EWJ@``&8/'T0`
M`/,/'OK_)=:H``!F#Q]$``#S#Q[Z_R7.J```9@\?1```\P\>^O\EQJ@``&8/
M'T0``/,/'OK_);ZH``!F#Q]$``#S#Q[Z_R6VJ```9@\?1```\P\>^O\EKJ@`
M`&8/'T0``/,/'OK_)::H``!F#Q]$``#S#Q[Z_R6>J```9@\?1```\P\>^E5(
MB>5!5%-(@^PPB7W<2(U]W$B)==!(C7702(E5R&1(BQ0E*````$B)5>A(C57(
MZ(C___](BS5IJ```2(L]FJ@``$B)\NAR0P``2(L%FZ@``(`X``^$'`$``$B+
M!6NH``!D2(L`@(@Z!````XM%W(UX!(U8`TAC_TC!YP/HN_[__TB+3=!$BT7<
M2(G&2(D%L:@``$B+`4B)!DB-!4-*``!(B48(2(T%<:@``$B+`$B)1A!(C04M
M2@``2(E&&$&#^`$/CBH!``!(@\$(08/``[@$````#Q^$``````!(BSE(8]"#
MP`%(@\$(2(D\UD0YP'7J2)A(BSTYJ```13'`2(GQ2,<$Q@````")VDB--2H>
M``#HI?O__X7`#X2'````2(L]#J@``$R-9>3H;?W__TR)YDB-/:I(``")PS'`
MZ)H:``!(A<!T<$B+/>:G``#H2?O__^C$_/__2(M%Z&1(*P0E*`````^%F@``
M`$B#Q#")V%M!7%W#Z$'\__](B06RIP``2(G'2(7`=''HK?S__TB+!3:G``!D
M2(L0QH*V"````.F[_O__2(L]AZ<``.B*^___Z6C___](BSU^IP``2(7_=`KH
M%#P``.EZ____2(T]?D<``$R)YN@`&@``2(D%6:<``$B)QTB%P`^$6/___^O2
MN`0```#I]_[__[\!````Z.?Z___HTOS__V:0\P\>^C'M28G17DB)XDB#Y/!0
M5$4QP#')2(T]T?W___\5PZ8``/1F+@\?A```````2(T]X:8``$B-!=JF``!(
M.?AT%4B+!5ZF``!(A<!T"?_@#Q^``````,,/'X``````2(T]L:8``$B--:JF
M``!(*?Y(B?!(P>X_2,'X`T@!QDC1_G042(L%):8``$B%P'0(_^!F#Q]$``##
M#Q^``````/,/'OJ`/6VF````=2M52(,]`J8```!(B>5T#$B+/3:F``#HN?G_
M_^AD____Q@5%I@```5W##Q\`PP\?@`````#S#Q[ZZ7?___\/'X``````54B)
MY4%7059!54%44[O_____9D@/;M-F#VS22('LF`(``&1(BQ0E*````$B)5<A(
MB?J+0CA(BW(X#\B)P$B)\4B)A4#]__](B?!(P>D@2,'H*$C![C@E`/\``$@)
M\$B)SDC!X0A(P>88@>$``/\`B?9("?!(BW)`2`G(2(F%2/W__XM"0$B)\4C!
MZ2`/R(G`2(F%4/W__TB)\$C![CA(P>@H)0#_``!("?!(B<Y(P>$(2,'F&('A
M``#_`(GV2`GP2(MR2$@)R$B)A5C]__^+0DA(B?%(P>D@#\B)P$B)A6#]__](
MB?!(P>XX2,'H*"4`_P``2`GP2(G.2,'A"$C!YAB!X0``_P")]D@)\$B+<E!(
M"<A(B85H_?__BT)02(GQ2,'I(`_(B<!(B85P_?__2(GP2,'H*$C![C@E`/\`
M`$@)\$B)SDC!X0A(P>88@>$``/\`B?9("?!("<A(B85X_?__BT)82(MR6&8/
M;Z50_?__#\B)P&8/;X5@_?__9@]OG7#]__](B86`_?__2(GP2(GQ2,'N.$C!
MZ"A(P>D@)0#_``!("?!(B<Y(P>$(2,'F&('A``#_`(GV2`GP2(MR8$@)R$B)
MA8C]__^+0F!(B?%(P>D@#\B)P$B)A9#]__](B?!(P>XX2,'H*"4`_P``2`GP
M2(G.2,'A"$C!YAB!X0``_P")]D@)\$B+<FA("<A(B868_?__BT)H2(GQ2,'I
M(`_(B<!(B86@_?__2(GP2,'H*"4`_P``2,'N.$@)\$B)SDC!X0A(P>88@>$`
M`/\`B?9("?!(BW)P2`G(2(F%J/W__XM"<$B)\4C!Z2`/R(G`2(F%L/W__TB)
M\$C![CA(P>@H)0#_``!("?!(B<Y(P>$(2,'F&('A``#_`(GV2`GP2`G(2(U-
MJ$B)A;C]__](C86H_?__9F8N#Q^$``````!F#V]HV/,/;PA(@\!`9@_OH%C_
M__]F#^^`:/___V8/[\UF#^^8>/___V8/[\QF#V_A9@]S\0%F#W/4'V8/Z\QF
M#V]@J&8/V\H/*4C8\P]O2-!F#^_,9@_OP68/;\AF#W/0'V8/<_$!9@_KP68/
MV\(/*4#H9@]O0+CS#V](X&8/[\AF#^_+9@]OV68/<_$!9@]STQ]F#^O+9@]O
M6,AF#]O*#RE(^/,/;TCP9@_OS68/;VB(9@_OZV8/[\UF#V_I9@]S\0%F#W/5
M'V8/Z\UF#]O*#RE("$@YP0^%(____TR+"DR+6A!(BWH@2(M:&$R)R$R)R4R+
MA4C]__](P>D;2,'@!4@)R`.%0/W__TZ-A`.9>8):C8PXF7F"6DR)V$@QV$@C
M0@A(,=B-/`%(BTH(2(M""$F)^DC!Z`)(P>$>2`G!3(G82<'J&XG.2#'P3"'(
M3#'83`'`28GX2<'@!4T)T$:-)`!,B<A-B<A)P>@"2,'@'DV)Y4P)P$R+A5#]
M__])P>T;2#'!08G"2"'Y3XV$`YEY@EI(,?%,`<%-B>!)P>`%30GH3(NM6/W_
M_T$!R$B)^4C![P)(P>$>18G`2HVT+IEY@EI("?E-B<5(,<B)STPAX$G![1M,
M,=!(`?!,B<9(P>8%3`GN3(NM8/W__P'&3(G@2<'L`DC!X!Z)]D^-E"J9>8):
M3`G@28GU2#'!2<'M&T&)Q$PAP4@Q^4P!T4F)\DG!X@5-">I,BZUH_?__00'*
M3(G!2<'H`DC!X1Y%B=)*C;POF7F"6DP)P4V)U4@QR$G![1M!B<A((?!,,>!(
M`?A,B==(P><%3`GO3(NM</W__P''2(GP2,'N`DC!X!Z)_T^-I"R9>8):2`GP
M28G]2#'!2<'M&XG&3"'13#'!3`'A28G\2<'D!4T)[$R+K7C]__]!`<Q,B=%)
MP>H"2,'A'D6)Y$^-A"B9>8):3`G138GE2#'(2<'M&T&)RD@A^$@Q\$P!P$V)
MX$G!X`5-">A,BZV`_?__00'`2(GX2,'O`DC!X!Y%B<!*C;0NF7F"6D@)^$V)
MQ4@QP4G![1N)QTPAX4PQT4@!\4R)QDC!Y@5,">Y,BZV(_?__`<Y,B>%)P>P"
M2,'A'HGV3XV4*IEY@EI,">%)B?5(,<A)P>T;08G,3"'`2#'X3`'028GR2<'B
M!4T)ZDR+K9#]__]!`<),B<!)P>@"2,'@'D6)TDJ-O"^9>8):3`G`38G52#'!
M2<'M&T&)P$@A\4PQX4@!^4R)UTC!YP5,">],BZV8_?__`<](B?%(P>X"2,'A
M'HG_3XVD+)EY@EI("?%)B?U(,<A)P>T;B<Y,(=!,,<!,`>!)B?Q)P>0%30GL
M3(NMH/W__T$!Q$R)T$C!X!Y)P>H"18GD3XV$*)EY@EI,"=!-B>5(,<%)P>T;
M08G"2"'Y2#'Q3`'!38G@2<'@!4T)Z$R+K:C]__]!`<A(B?E(P>\"2,'A'D6)
MP$J-M"Z9>8):2`GY38G%2#'(2<'M&XG/3"'@3#'02`'P3(G&2,'F!4P)[DR+
MK;#]__\!QDR)X$G![`)(P>`>B?9/C90JF7F"6DP)X$F)]4@QP4G![1M!B<1,
M(<%(,?E,`=%)B?))P>(%30GJ3(NMN/W__T$!RDR)P4C!X1Y)P>@"18G22HV\
M+YEY@EI,"<%-B=5(,<A)P>T;08G(2"'P3#'@2`'X3(G72,'G!4P)[TR+K<#]
M__\!QTB)\$C![@)(P>`>B?]/C:0LF7F"6D@)\$F)_4@QP4G![1N)QDPAT4PQ
MP4P!X4F)_$G!Y`5-">Q&C30A3(G12<'J`DC!X1Y,"=%,BY7(_?__2#'(08G,
M2"'X3XV$$)EY@EI-B?)(,?!)P>H;3`'`38GP2<'@!4T)T$R+E=#]__]!`<!(
MB?A(P>`>2,'O`D6)P$J-M!:9>8):2`GX38G"2#'!2<'J&XG'3"'Q3#'A2`'.
M3(G!2,'A!4P)T4V)\DG![@))P>(>B<E-"?)(`<Y(BXW8_?__3#'008GU3"'`
M28V,#)EY@EI-B>Q(,?A)P>P;2`'(3(GI2,'A!4P)X8G)2`'(3(G!2<'H`DC!
MX1Y!B<1,"<%-B=!%B=)),<A$,<9,BX7@_?__2HV\!Z'KV6Y-B>!(`?=,B>9)
MP>@;2,'F!4P)QHGV2`'W3(GN2,'F'DG![0)!B?A,`Y7H_?__3`GN28G-B<E(
M`XWP_?__23'U1#'H38G%38V4`J'KV6Y,B<!)P>T;2,'@!4P)Z(G`20'"3(G@
M2<'L`DC!X!Y%B=5,">!)B?2)]D@#M?C]__]),<1$,>=-B>Q(C;PYH>O9;DR)
MZ4G![!M(P>$%3`GAB<E(`<],B<%)P>@"2,'A'D&)_$P)P4F)P(G`23'(13'0
M38GB3HV$!J'KV6Y,B>9)P>H;2,'F!4P)UHGV20'P3(GN2<'M`DC!YAY%B<),
M">Y)B<U(`X4`_O__B<E),?5(`XT(_O__1#'O38G52(V\.*'KV6Y,B=!)P>T;
M2,'@!4P)Z(G`2`''3(G@2<'L`DC!X!Y!B?U,">!)B?2)]D@#M1#^__]),<1%
M,>!-B>Q.C80!H>O9;DR)Z4G![!M(P>$%3`GAB<E)`<A,B=%)P>H"2,'A'D6)
MQ$P)T4F)PHG`2`.%&/[__TDQRD0QUTV)XDB-O#ZAZ]EN3(GF2<'J&TC!Y@5,
M"=:)]D@!]TR)[DG![0)(P>8>08GZ3`GN28G-B<E),?5(`XT@_O__13'H38G5
M3HV$`*'KV6Y,B=!)P>T;2,'@!4P)Z(G`20'`3(G@2<'L`DC!X!Y%B<5,">!)
MB?2)]D@#M2C^__]),<1$,>=-B>Q(C;PYH>O9;DR)Z4G![!M(P>$%3`GAB<E(
M`<],B=%)P>H"2,'A'D&)_$P)T4F)PHG`2`.%,/[__TDQRD4QT$V)XDZ-A`:A
MZ]EN3(GF2<'J&TC!Y@5,"=:)]DD!\$R)[DG![0)(P>8>18G"3`GN28G-B<E)
M,?5$,>]-B=5(C;PXH>O9;DR)T$C!X`5)P>T;2`.-./[__TP)Z(G`2`''3(G@
M2<'L`DC!X!Y!B?U,">!)B?2)]D@#M4#^__]),<1%,>!-B>Q.C80!H>O9;DR)
MZ4G![!M(P>$%3`GAB<E)`<A,B=%)P>H"2,'A'D6)Q$P)T4F)PHG`2`.%2/[_
M_TDQRD0QUTV)XDB-O#ZAZ]EN3(GF2<'J&TC!Y@5,"=:)]D@!]TR)[DG![0)(
MP>8>08GZ3`GN28G-B<E),?5%,>A-B=5.C80`H>O9;DR)T$G![1M(P>`%3`GH
M2`.-4/[__XG`20'`3(G@2<'L`DC!X!Y%B<5,">!)B?2)]D@#M5C^__]),<1$
M,>=-B>Q(C;PYH>O9;DR)Z4G![!M(P>$%3`GAB<E(`<],B=%)P>H"2,'A'D&)
M_$P)T4F)PHG`2`.%8/[__TDQRD4QT$V)XDZ-A`:AZ]EN3(GF2<'J&TC!Y@5,
M"=:)]DD!\$R)[DG![0)(P>8>18G"3`GN28G-B<E),?5$,>]-B=5(C;PXH>O9
M;DR)T$G![1M(P>`%3`GHB<!(`<=,B>!(P>`>2<'L`D&)_4@#C6C^__],">!)
MB?2)]D@#M7#^__]),<1%,>!.C:0!H>O9;DR)Z4V)Z$G!Z!M(P>$%3`G!B<E)
M`<Q,B=%)P>H"2,'A'D6)X$P)T4F)PHG`2`.%>/[__TDQRD0QUTV)PDB-O#ZA
MZ]EN3(G&2<'J&TC!Y@5,"=9-B>I)P>T"2<'B'@'W2(G.B<E-">J)_TPQUDV)
MUD6)U40QYDF)_$B-M#"AZ]EN2(GX2<'L&TC!X`5,">!$C20&3(G&2<'H`KC<
MO!N/2,'F'DP)QDD)]D&)\$TAPDDA_DT)UDR+E8#^__])`<),`=%-B>),`?%-
MB>9)P>(%2<'N&TT)\D$!RDB)^4C![P)(P>$>18G22`GY2`G.28G.B<],(>9-
M(<9)"?9(B[6(_O__2`'&3`'N38G53`'V38G62<'E!4G![AM-"?5)B<Y!`?5,
MB>9)P>P"2,'F'D6)[4P)YD&)]$D)]DTAUDPAX4P)\4R+M9#^__])`<9-`<9-
MB>A,`?%-B>Y)P>`%2<'N&TT)\$$!R$R)T4G!Z@)(P>$>18G`3`G12`G.28G.
M08G*3"'N32'F20GV2(NUF/[__T@!QD@!_DR)QTP!]DV)QDC!YP5)P>X;3`GW
M28G.`?=,B>Y)P>T"2,'F'HG_3`GN08GU20GV32'&3"'I3`GQ3(NUH/[__TD!
MQDT!YDF)_$P!\4F)_DG!Y`5)P>X;30GT00',3(G!2<'H`DC!X1Y%B>1,"<%(
M"<Y)B<Y!B<A((?Y-(>Y)"?9(B[6H_O__2`'&3`'638GB3`'V38GF2<'B!4G!
M[AM-"?))B<Y!`?)(B?Y(P>\"2,'F'D6)TD@)_HGW20GV32'F2"'Y3`GQ3(NU
ML/[__TD!QDT![DV)U4P!\4V)UDG!Y05)P>X;30GU00'-3(GA2,'A'DG![`)%
MB>U,">%("<Y)B<Y!B<Q,(=9)(?Y)"?9(B[6X_O__2`'&3`'&38GH3`'V38GN
M2<'@!4G![AM-"?!)B<Y!`?!,B=9)P>H"2,'F'D6)P$P)UD&)\DD)]DTA[DPA
MT4P)\4R+M<#^__])`<9)`?Y,B<=,`?%-B<9(P><%2<'N&TP)]P'/3(GI2<'M
M`DC!X1Z)_TP)Z4@)SDF)SD&)S4PAQDTAUDD)]DB+M<C^__](`<9,`>9)B?Q,
M`?9)B?Y)P>0%2<'N&TT)]$F)SD$!]$R)QDG!Z`)(P>8>18GD3`G&08GP20GV
M22'^3"'!3`GQ3(NUT/[__TD!QDT!UDV)XDP!\4V)YDG!X@5)P>X;30GR00'*
M2(GY2,'O`DC!X1Y%B=)("?E("<Y)B<Z)STPAYDTAQDD)]DB+M=C^__](`<9,
M`>Y-B=5,`?9-B=9)P>4%2<'N&TT)]4F)SD$!]4R)YDG![`)(P>8>18GM3`GF
M08GT20GV32'63"'A3`GQ3(NUX/[__TD!QDT!QDV)Z$P!\4V)[DG!X`5)P>X;
M30GP00'(3(G12<'J`DC!X1Y%B<!,"=%("<Y)B<Y!B<I,(>Y-(>9)"?9(B[7H
M_O__2`'&2`'^3(G'3`'V38G&2,'G!4G![AM,"?=)B<X!]TR)[DG![0)(P>8>
MB?],">Y!B?5)"?9-(<9,(>E,"?%,B[7P_O__20'&30'F28G\3`'Q28G^2<'D
M!4G![AM-"?1!`<Q,B<%)P>@"2,'A'D6)Y$P)P4@)SDF)SD&)R$@A_DTA[DD)
M]DB+M?C^__](`<9,`=9-B>),`?9-B>9)P>(%2<'N&TT)\DF)SD$!\DB)_DC!
M[P)(P>8>18G22`G^20GVB?=-(>9((?E,"?%,B[4`____20'&30'N38G53`'Q
M38G62<'E!4G![AM-"?5!`<U,B>%)P>P"2,'A'D6)[4P)X4@)SDF)S$&)STPA
MUDDA_$D)]$B+M0C___](`<9,`<9-B>A,`>9-B>Q)P>`%2<'L&TT)X$$!\$R)
MUDG!Z@)(P>8>18G`3`G628G*08GT20GR32'J3"'A3`G13(N5$/___TD!PD@#
MA1C___],`==-B<),`?A,B[TX____2`'/3(G!2<'J&TC!X05,"=&)R4@!STR)
MZ4G![0)(P>$>08GZ3`GI2`G.28G-08G.3"'&32'E20GU28UT!0!,B=!-B=5)
MP>T;2,'@!4P)Z(G`2`'&3(G`2<'H`DC!X!Y!B?5)"<"XUL%BRDPQP3'Y2(N]
M(/___T@!QTP!YTV)[$@!^4R)[TG![!M(P><%3`GG38G4B?](`?E)P>0>20''
M2<'J`HG/30GB38G$18G`33'403'T2(NU*/___T@!QDP!]DF)_DP!YDF)_$G!
M[AM)P>0%30GT38GN2<'M`DG!YAY%B>1-"?5,B[4P____3`'F08GT20'&30'P
M38G633'N03'.3(GA30'P38GF2,'A!4G![AM,"?&)R4D!R$B)^4C![P)(P>$>
M18G&2`G/1(G138GJ23'Z3`'Y3(N]0/___T$Q\DJ--!%,B?%-B?)(P>$%2<'J
M&TD!QTP)T8G)2`'.3(GA2<'L`DC!X1Y!B?),">%%B>Q)B?V)_TDQS4T!_$R+
MO5C___]%,<5/C00L38G438G52<'M&TG!Y`5-">Q-B?5)P>X"2<'E'D6)Y$T)
M[DR+K4C___]-`>!%B<1)`<5,`>])B<V)R4TQ]4$Q]4R)YDP![TV)Y4C!Y@5)
MP>T;3`GNB?9(`?=,B=9)P>H"2,'F'D&)_4P)UDR+E5#___])`<),`=%-B?))
M,?)%,<))`<=.C0013(GI38GJ2<'J&TC!X05,"=&)R4D!R$R)X4G![`)(P>$>
M18G"20G,1(GQ28GVB?9-,>9,`?E,B[UH____03'^2HT\,4R)T4V)UDD!QTG!
M[AM(P>$%3`GQB<E(`<],B>E)P>T"2,'A'D&)_DP)Z4R+K6#___])`<5,`>Y-
MB>5),<U%,<5.C00N3(GV38GU2<'M&TC!Y@5,">Z)]DD!\$R)UDG!Z@)(P>8>
M18G%20GR1(GF28G,B<E,`?Y-,=1,B[UX____03'\2HT\)DR)[DV)[$D!QTG!
M[!M(P>8%3`GFB?9(`?=,B?9)P>X"2,'F'D&)_$P)]DR+M7#___])`<9,`?%-
MB=9),?9%,<9.C00Q3(GA38GF2<'N&TC!X05,"?&)R4D!R$R)Z4G![0)(P>$>
M18G&20G-1(G128GRB?9-,>I,`?E,BWV(03'Z2HT\$4R)\4V)\DG!ZAM(P>$%
M3`G1B<E(`<],B>%)P>P"2,'A'D&)^DP)X4R+98!)`<1,`>9-B>Q)`<=),<Q%
M,<1.C00F3(G638G42<'L&TC!Y@5,">:)]DD!\$R)]DG![@)(P>8>18G$20GV
M1(GN28G-B<E-,?5,`?Y,BWV803']2HT\+DR)YDV)Y4G![1M(P>8%3`GNB?9(
M`?=,B=9)P>H"2,'F'D&)_4P)UDR+59!)`<),`=%-B?)),?)%,<).C0013(GI
M38GJ2<'J&TC!X05,"=&)R4D!R$R)X4G![`)(P>$>18G"20G,1(GQ28GV20''
M33'F3`'YB?9,BWVH03'^3(G720'.3(G12,'O&TD!QTC!X05("?F)R4D!SDR)
MZ4G![0)(P>$>1(GW3`GI3(MMH$D!Q4P![DV)Y4DQS44QQ4Z-!"Y(B?Y)B?U)
MP>T;2,'F!4P)[HGV20'P3(G62<'J`DC!YAY%B<5)"?)$B>9)B<R)R4TQU$P!
M_D4Q]$V)[DP!YDV)[$G![AM)P>0%30GT28G^18GD3`'F2<'F'DC![P)!B?1,
M"?=,BW6P20'&2`-%N$P!\4V)UDP!R$6)TDDQ_DP!T$4QQDV)X$P!\4V)YDG!
MX`5)P>X;30GP1`'!38GH2<'M`DG!X!Z)R4T)Q4F)^`-Z($TQZ$$!W4B)>B!$
M,<9)B<A,B6H82`'P2(G.2<'H&P-*"$C!Y@5(B4H(3`G&`?!(B0),B>!)P>P"
M2,'@'DP)X$0!V$B)0A!(BT7(9$@K!"4H````=1)(@<28`@``6T%<05U!7D%?
M7</H#>/__V9F+@\?A```````9I!52(GE05=!5D%505132(/L&$B+!:B,``!(
MB77(3(LP387V#X2?````#[8'28G]A,!T!#P]=5I%,>1)BQY(A=MT-4UCY$V)
M]V8/'X0``````$R)XDR)[DB)W^CBX/__A<!U!T*`/",]=$=)BU\(28/'"$B%
MVW7:2(/$&$B)V%M!7$%=05Y!7UW##Q^$``````!)B?Q!#[9$)`%)@\0!A,!T
M!#P]=>Y%*>SKCV8/'T0``$R)^4B+1<A*C5PC`4PI\4C!^0.)".NO,=OKJP\?
M1```54B)Y4%7059!54%428G\4TB#[`A(BP75BP``3(LP387V=&1!#[8$)(3`
M#X3,````/#T/A,0```!-B>=!#[9'`4F#QP&$P'0$/#UU[T4IYTV++DV%[70P
M36/_3(GS#Q\`3(GZ3(GF3(GOZ`+@__^%P'4(0X!\/0`]="9,BVL(2(/#"$V%
M[7792(/$"%M!7$%=05Y!7UW#9BX/'X0``````$B+!4F+``!,*?-(P?L#2(L`
M2&/;2(T$V$B+4`A(B1!(A=)T'&9F+@\?A```````D$B+4!!(@\`(2(D02(72
M=?!(BP4)BP``3(LP387V=)A!#[8$)(3`#X4T____13'_Z4O___]F9BX/'X0`
M`````)!52(GE05=!5D%505132('LJ````&1(BP0E*````$B)1<@QP$B%_W0(
M@#\`2(G[=2A(BT7(9$@K!"4H````#X4L`0``2('$J````%M!7$%=05Y!7UW#
M#Q\`Z./?__])B<5(A<!TRTR)[^BSX?__2(7`#X2Z````@'@3+DR-8!-U$$&`
M?"0!`'3=#Q^$``````"`>!,N#X2N````2(G?Z'[?__],B>=)B<;H<]___T6-
M?`8"36/_3(G_Z+/>__]-B>%)B=A,B?I)B<9(B<>^`@```#'`2(T-:BH``.C1
MX/__3(GW2(VU,/___^A"W___3(GW@_C_=!*+A4C___\E`/```#T`0```=&#H
MD][__TR)]^C[WO__3(GOZ`/A__](A<`/A5#___]F+@\?A```````3(GOZ&C@
M__](B=_H<-[__^GK_O__#Q\`08!\)`$N#X5&____08!\)`(`#X0%____Z37_
M__\/'P#HD_[__^N>Z*S?__]F9BX/'X0``````)#S#Q[Z54B-#21J``!(C36W
M*0``2(GE4TB#[`A(BQUNB0``2(L5;XD``&1(BSOH+N#__V1(BSM(BUWX13')
M2(T5_!H``$R-!3DK``!(C364*0``R4R)P>F5WO__#Q]$``!52(GE059!54%4
M4TB![``0``!(@PPD`$B#[!"Z_P\``&1,BR0E*````$R)9=A)B?1,C:W0[___
M2(G[2(T]6BD``$R)[NB7WO__A<!^%HG!@^@!2&/0@+P5T.___P!U087`=35(
MBP7&B```3(GB2(G>9$B+..AGW?__2(M%V&1(*P0E*````'5+2('$$!```%M!
M7$%=05Y=PXG!9@\?1```3&/QOB\```!,B>],B?+H?=S__TB%P'2K2(L%<8@`
M`$R)\4R)ZDB)WF1(BSCH_]W__^NFZ&C>__\/'X0``````%5(B>5!5T%6055)
MB?5!5$F)_%-(@^PH@#X]=01)@\4!3(GOZ#C=__](B47`2(L%[8<``$B+`$B)
M1<A,BSA!#[8$)(3`#Y7"/#T/E<`@PHA5N`^%"0(``#';387_#X16`@``3(MU
MR$ACVP\?@`````!(B=I,B>9,B?_H(MS__X7`=0M!@#P?/0^$LP```$V+?@A)
M@\8(387_==9(BT7(9I!(@\`(1(GZ08/'`4B#.`!U[XU*`TACR4C!X0.+!>^'
M``"%P`^%MP$``$B)STB)3;C'!=:'```!````Z-';__](B<=(A<`/A"<!``!)
M8]](BW7(2(M-N$C!XP-(B=KH+M[__TB)QTB+!12'``!(B3A(B<9%C4<!36/`
M2L<$QP````!!#[8$)$B+-H3`#Y7"/#U(B77(#Y7`(<*(5;CK,6:028U<'P%(
MB=_H$]S__TB+=<!(.?`/@\X```!(BT7(38GP22G`2<'X`TECV$C!XP.`?;@`
M#X0X`0``3(G@#Q]```^V4`%(@\`!A-)T!8#Z/77O3"G@2)A(BW7`2(U\!@+H
M#-O__TB+=<A(B00>2(7`=&%(BP5HA@``28U,)`%(BP!(BQ0800^V!"2(`CP]
M=":$P'41ZR!F9BX/'X0``````#P]=!$/M@%(@\(!2(/!`8@"A,!UZ\8"/3'`
M9@\?1```00^V3`4`B$P"`4B#P`&$R77N2(/$*%M!7$%=05Y!7UW##Q^`````
M`#'`9F8N#Q^$``````!F9BX/'X0``````$$/ME0%`(@4`TB#P`&$TG7O2(/$
M*%M!7$%=05Y!7UW#3(GC#[9#`4B#PP&$P'0$/#UU\$0IX^G>_?__#Q]$``!(
MBWW(2(G.Z(3<__](B<=(BP6*A0``2(DX2(7_#X1P____26/?2(G&2,'C`^EA
M_O__,<#IWO[__[D0````13'_Z?;]__]F9BX/'X0``````/,/'OI(BP5UA0``
M2(L5=H4``$B-#0=F``!(C36:)0``9$B+..DGW/__#Q^``````/,/'OI52(GE
M055!5%-(@>P`$```2(,,)`!(@>P`$```2(,,)`!(@^PH9$B+!"4H````2(E%
MV#'`2(V=T.___TR-I<#?___HU=G__TR-#70E``"Z`1```$B)WT&)P$B-#68E
M``"^`@```#'`Z(#;__](B=^Z`!```$R)YNB`VO__,?^%P'@R1(UH`4B)PTUC
M[4R)[^@8V?__2(G'2(7`=!A(8]M,B>E,B>9(B=KH7]G__\8$&`!(B<=(BT78
M9$@K!"4H````=1%(@<0H(```2(GX6T%<05U=P^B#VO__#Q\`\P\>^ND7____
M#Q^``````/,/'OI52(GE05=!5D%505132('L`!```$B##"0`2('LN````$B)
MO2CO__](B;4@[___9$B+!"4H````2(E%R$B+!>J#``!,BR!-A>0/A%@"``!,
MC36-)```38GW00^V1P%)@\<!A,!T!#P]=>])BQPD32GW2(7;=$)-8_]!O0D`
M``!-.>]-#T;O#Q^``````$R)ZDR)]DB)W^@2V/__A<!U"T*`/#L]#X3S`0``
M28M<)`A)@\0(2(7;==5(B[TH[___OB\```#H5-G__TB%P'0_2(N=*.___S'`
M2(T]$"0``$B)WN@G^___2(G82(M5R&1(*Q0E*`````^%L@$``$B-9=A;05Q!
M74%>05]=PV:02(N](.___TR-+>`C``!,C27?)```Z";9__],B>Y(B<?H6]G_
M_TF)QDB%P'2408`^``^$^P```&8/'X0``````$B%VW033(GV2(G?Z"#9__^%
MP`^$N@```$R)]^@`V/__28U4!O])B<=).=9R'^LM9F8N#Q^$``````!F#Q]$
M``#&`@!(@^H!23G6=`6`.B]T[TR)]^C'U___28G'2(N]*.___^BXU___28U$
M!P%(/?\/```/APC___](@^P(_[4H[___3(GA38GP3(V]P.___[H`$```3(T-
M%",``#'`O@(```!,B?_H!=G__TB-M3#O__],B?_H=M?__UI9A<!U$HN%2.__
M_R4`\```/0"```!T3DR)[C'_Z&38__])B<9(A<`/A)G^__]!@#X`#X4.____
M2(7;=`6`.RYT%$&_`0```$R--98B``#I3O___V:0@'L!`'2\Z^0/'X0`````
M`+X!````3(G_Z)/8__^%P'6A3(G^2(T]9B(``.B`^?__3(G_Z+C7___I3_[_
M_P\?`$J-7#L!Z1'^__\QV^D*_O__Z+K7__]F+@\?A```````\P\>^E6^+P``
M`$B)Y5-(B?M(@^P(Z`;7__](C5`!2(7`2`]%VDB)WTB+7?C)Z5[7__]F9BX/
M'X0```````\?`/,/'OI52(GE05132('L`!```$B##"0`2(/L$&1(BP0E*```
M`$B)1>@QP$B%_P^$S0```(`_`$B)^P^$P0```.@LUO__2(G"2(U``4@]`!``
M``^'X0```$R-I>#O__],B>>#^`AR#HG!2(G>P>D#\TBE2(GS,<FH!'0)BPN)
M#[D$````J`)T#D0/MP0+9D2)!`](@\$"J`%T!P^V!`N(!`])C404_TDYQ'(2
MZQ4/'T``Q@``2(/H`4PYX'0%@#@O=.^^+P```$R)Y^@2UO__2(7`="U).<1R
M6$R)Y^APUO__2(M5Z&1(*Q0E*````'5-2('$$!```%M!7%W##Q]$``!(BT7H
M9$@K!"4H````=2U(@<00$```2(T]TB```%M!7%WI*M;__V8N#Q^$``````#&
M``#KHP\?`#'`ZZ3H+];__V9F+@\?A```````#Q]``/,/'OI52(T]ZB```#'`
M2(GE05=!5D%505132(/L&.C-\___2(T]U2```#'`Z+_S__](C3W/(```,<#H
ML?/__TB-/<H@```QP.BC\___2(T]PR```#'`Z)7S__](C3W%(```,<#HA_/_
M_TB-/28@```QP.AY\___2(T]M2```#'`Z&OS__](C3VQ(```,<#H7?/__TB-
M/:T@```QP.A/\___,<!(C3WW'P``Z$'S__](BP4J?P``2(L82(7;#X3)`0``
M3(TUZ1\``$V)]4$/MD4!28/%`83`=`0\/77O3(L[32GU387_=$9)8\5!O!$`
M``!)B=U,.>!(B47(3`]&X)!,B>),B?9,B?_H4M/__X7`=0](BT7(08`\!ST/
MA(\!``!-BWT(28/%"$V%_W723(TUCA\``$V)]4$/MD4!28/%`83`=`0\/77O
M3(L[32GU387_=$I)8\5!O!(```!)B=U,.>!(B47(3`]&X`\?1```3(GB3(GV
M3(G_Z.+2__^%P'4/2(M%R$&`/`<]#X1/`0``38M]"$F#Q0A-A?]UTDR--3`?
M``!!#[9&`4F#Q@&$P'0$/#UU[TR+*TB-!14?``!)*<9-A>UT6DECQD&\$```
M`$F)WTV)[DPYX$B)1<A,#T;@9F8N#Q^$```````/'P!,B>)(C37;'@``3(GW
MZ%[2__^%P'4/2(M%R$&`/`8]#X3[````38MW"$F#QPA-A?9USDR-);P>``!-
MB>9!#[9&`4F#Q@&$P'0$/#UU[TTIYDV%[71&36/V0;\1````33G^30]&_F9F
M+@\?A```````3(GZ3(GF3(GOZ/+1__^%P'4,0X!\-0`]#X2J````3(MK"$B#
MPPA-A>UUU4B#Q!A(C37&'@``2(T]>AX``#'`6T%<05U!7D%?7>D2]?__9I!)
MC70'`4B-/8$>```QP.C]]/__2(L%%GT``$B+&$B%VP^%6/[__^NS#Q^$````
M``!)C70'`4B-/64>```QP.C-]/__2(L%YGP``$B+&$B%VP^%F/[__^F`____
M#Q]$``!)C70&`4B-/7H=```QP.B=]/__Z6/___]+C70U`4B-/?\=``#HA_3_
M_^E-____9I#S#Q[Z54B)Y4%7059!54%44TB#[`A(BP6$?```3(L@387D=&-,
MC3W('0``38G^00^V1@%)@\8!A,!T!#P]=>])BQPD32G^2(7;=#Q-8_9!O0H`
M``!-.>Y-#T;N#Q]$``!,B>I,B?Y(B=_HLM#__X7`=0="@#PS/70G28M<)`A)
M@\0(2(7;==E(@\0(,<!;05Q!74%>05]=PP\?A```````0@^V5#,!A-(/E,"`
M^C`/E,)(@\0("=!;05R#\`%!74%>#[;`05]=PP\?A```````\P\>^E5(B>5(
M@>S0````2(FU6/___TB)E6#___](B8UH____3(F%</___TR)C7C___^$P'0@
M#RE%@`\I39`/*56@#RE=L`\I9<`/*6W0#REUX`\I??!D2(L$)2@```!(B85(
M____,<!(C4402(GZ2(V-,/___TB)A3C___^^`@```$B-A5#___](B85`____
M2(L%@7L``,>%,/___P@```#'A33___\P````2(L`2(G'Z(K0__^__P```.A@
MS___54B)Y4%505133(V<)```__](@>P`$```2(,,)`!,.=QU[TB#[!BZ`@``
M`#'V9$R++"4H````3(EMV$&)_4B-G=#__O_H=]'__TR-8/],B>)(P?H_2,'J
M,$F-!!0/M\!(*=!)*<0/B+$````/'T0``#'23(GF1(GOZ$/1__](@_C_#X2L
M````N@@``0!(B=Y$B>_HZ<[__X/X_P^$A0```$B82(/X!W9@2(U$`_A(.=AR
M5DB-%<=Z``#K'F9F+@\?A```````9BX/'X0``````$B#Z`%(.=AR+TB+"$@Y
M"G7O2"G83`'@2(M5V&1(*Q0E*````'5+2('$&``!`%M!7$%=7<,/'T``28'L
M```!`$F!_```__\/A53___](Q\#_____Z\)(C3UO&P``,<#H#?[__TB-/50;
M```QP.C__?__Z`K0__]F+@\?A```````\P\>^E5(B>7H,]#__XG'Z+S.__](
MA<!T`TB+`%W#9I#S#Q[Z54B)Y4%7059!54%43(TE(!L``%--B>9(@^P82(L%
M>GD``$B)?<A,BSA-A?]T5$$/MD8!28/&`83`=`0\/77O28L?32GF2(7;=#A-
M8_9!O1````!-.>Y-#T;N9I!,B>I,B>9(B=_HLLW__X7`=0="@#PS/70O28M?
M"$F#QPA(A=MUVDB+=<A(C6783(GG,<!;05Q!74%>05]=Z=[P__]F#Q]$``!*
MC5PS`8`[`'343(M]R$R)_^@BSO__2(G?28G%Z!?.__]-C70%`DR)]^A:S?__
M2(/L"$R)\DV)^%-)B<6^`@```$B)QTR-#7L9``!(C0UZ&@``,<#H;\___UA,
MB>Y:ZX(/'X0``````/,/'OI52(GE05=!5D%505132('L6`$``$B)O9C^___S
M#WX%B70``&1(BP0E*````$B)1<A(C044&0``2,>%\/[__P````!(QX4H____
M`````$C'A=#^__\`````9D@/;LA(C07@&0``9@]LP69(#V[02(T%V!D```\I
MA>#^__]F2`]NV/,/?@4L=```2(T%P1D``$B)A<C^__](BP7O=P``9@]LP@\1
MA0C___],BSCS#WX%"70``&8/;,,/$848____387_=&-,C35X&```3(GR#[9"
M`4B#P@&$P'0$/#UU\$F+'TPI\DB%VW0^2&/20;P)````3#GB28G53`]&XI!,
MB>),B?9(B=_H`LS__X7`=0M"@#PK/0^$BP,``$F+7PA)@\<(2(7;==;HX<W_
M_XG'Z&K,__](A<`/A'0&``!,BSA-A?\/A&@&``!,B?_H?<S__TB-7``!2(G?
M28G<Z+W+__]%#[8'28G&28G%183`=%]F9BX/'X0```````\?`$B)VD4/ML!,
MB?<QP$B-#<H8``"^`@```$F#QP'HO\W__TPYXTR)XD4/M@=(#T/32(G02"G8
M2(/``D@YT$@/0L)(*=-)@\8"2(U<`_Y%A,!UKTB+!;AV``!,B:VH_O__3(V]
M`/___TR--108``!,BRA-A>T/A)$````/'X``````00^V!H3`#X24`@``/#T/
MA(P"``!-B?1!#[9$)`%)@\0!A,!T!#P]=>Y%*?1)BUT`2(7;=#5-8^0/'X0`
M`````$R)XDR)]DB)W^C"RO__A<!U"T*`/",]#X3#`0``28M="$F#Q0A(A=MU
MUDV+=PA-A?9T%TB+!19V``!)@\<(3(LH387M#X5V____3(NMJ/[__TR-O>#^
M__],C;4P____ZQ(/'X``````/0"@``!T-DF#QPA)BQ](A=MT2X`[``^$Z`0`
M`$R)]DB)W^@QS/__A<!UW(N%2/___R4`\```/0!```!UP[X"````2(G?Z'[,
M__^%P'6Y2(G?Z+++__](B<-(A<!TJ4B)W^C"RO__3(GO28G&Z+?*__]!C80&
M!`0``$QC^$R)_TR)O9#^___H[<G__TF)V$R)^KX"````2(T-)A<``$B)QTB)
MPTB)A:C^__]!54R-#046```QP%%(C0W]%@``Z/;+__](B=^^P`$``.AIS/__
M7T%8@_C_=1+H',O__T2+"$&#^1$/A1\%``!(C84P____2(N]J/[__TB)QDB)
MA8#^___H4LO__XG#A<`/A"\!``!(BX68_O__3(N%J/[__[X"````2(T53A<`
M`$B+"$B+!?QT``!(BS@QP.CJR/__2,>%H/[__P````!(BT7(9$@K!"4H````
M#X56!@``2(N%H/[__TB-9=A;05Q!74%>05]=PV8/'T0``$J-7",!@#L`#X0\
M_O__2(VU,/___TB)W^C#RO__A<`/A27^__^+A4C___\E`/```#T`0```=`L]
M`*````^%"/[__[X"````2(G?Z`'+__^%P`^%\_W__TB)WTR+K:C^___H*LK_
M_TB)PTB%P`^%=/[__^GZ_?__9@\?A```````13'DZ83]__]*C5PK`8`[``^$
M=/S__TB)W^@R^O__2(M%R&1(*P0E*`````^%B04``$B-9=A(B=];05Q!74%>
M05]=Z<G)__^+A4C___\E`/```#T`0```#X6[_O__1(NE3/___^@'RO__03G$
M#X6F_O__BX5(____)?\!```]P`$```^%D/[__TB+O9#^___H[,?__TB)A:#^
M__](BP5.<P``3(L@387D='Q(C17A%```#[9"`4B#P@&$P'0$/#UU\$V+-"1(
MC07&%```2"G"387V=%),8^JX!0```$R)I8C^__]).<5-B>])#T;%28G%3(GJ
M2(TUF!0``$R)]^ANQ___A<!U"T.`/#X]#X13`P``38MT)`A)@\0(387V==%,
MBZ6(_O__2(N%F/[__TB+`$B)A8C^__],B[V(_O__3(G_Z.K'__])B<6#^`-^
M,DB82(TU>10``$F-?`?\Z-_(__^%P'4;08/]!`^$?P,``$&-1?M(F$&`/`<O
M#X1N`P``387D='M,C3VW$P``3(G^#[9&`4B#Q@&$P'0$/#UU\$V+-"1,*?Y-
MA?9T54AC]D&]"@```(F=F/[__TR)XTPY[DF)]$P/1NYF#Q^$``````!,B>I,
MB?Y,B??HDL;__X7`=0M#@#PF/0^$5@(``$R+<PA(@\,(387V==:+G9C^__](
MB[V(_O__,?8QP$R-/3$3``#HF<?__T&)Q87`#X5U`@``3(G_2(TU0!,``#'`
MZ)WI__],C2W:$P``3(T]P1,``.BJQO__056^`@```$R-#6P2``!03(NUD/[_
M_TB-#9$3```QP$R+I:#^__],BX6H_O__3(GR3(GGZ$+(__]86NM'9@\?1```
MZ'/'__^#.!%U2>A9QO__@\,!2(/L"$R)^4%53(T-%A(``$R)\DR)YU.^`@``
M`%!,BX6H_O__,<#H^\?__TB#Q""^P`$``$R)Y^AJR/__@_C_=*U(B[VH_O__
MZ#G&__](BYV@_O__2(T]L1$``#'`2(G>Z-'H__](B=_H2??__^E%_/__,=OI
M4_O__TR-M<#^__],C25V$@``9F8N#Q^$```````/'T``2(L%N7```$R+*$V%
M[71G00^V!"2$P`^$O````#P]#X2T````38GG00^V1P%)@\<!A,!T!#P]=>]%
M*>=)BUT`36/_2(7;="]F#Q^$``````!,B?I,B>9(B=_HXL3__X7`=0="@#P[
M/71/28M="$F#Q0A(A=MUVDV+9@A)@\8(387D#X5Y____OPT```!!O`T```"[
M#0```.BTQ/__3(T]R1$``$&X4P```$F)QDF)Q>G\^/__#Q]``$J-?#L!@#\`
M=+3H&<;__TF)QTB%P`^%J/C__^NA#Q\`13'_Z5O___](BX68_O__3(N%J/[_
M_[X"````2(T5%A(``$B+"$B+!01P``!(BS@QP.CRP___Z0/[__]##[9$)@&+
MG9C^__^$P`^$J?W__SPP#X7#_?__Z9S]__](BX68_O__2XUT/@%(BSCH2.O_
M_TB+#7%O``!(B86(_O__3(LA2(7`#X6E_/__Z8_\__^)Q^A"]/__28G$2(7`
M#XAX_?__,=)(C7#V1(GOZ.C%__](C;6Z_O__N@8```!$B>_HE,/__TB#^`8/
MA>D```"!O;K^__\`0T%#=%E,C3U:$```Z33]__](BX68_O__3(MH"$V%[0^$
M?OS__TR)[^@FQ/__2(/X`P^&;/S__TF-?`7\2(TUM1```.@;Q?__A<!,#T6M
MB/[__TR)K8C^___I1?S__V:!O;[^__](176<,=))C70DSD2)[^A+Q?__2(NU
M@/[__[HH````1(GOZ/?"__](@_@H=5!(C06>$```QH58____`$B-#6$0``"^
M`@```%!,C0TO#P``,<#_M8#^__],BX6H_O__2(N5D/[__TB+O:#^___H#<7_
M_UE>Z2']___H<<3__TB-/100```QP.A3\O__#Q\`\P\>^E5(B>5!5T%6055!
M5%-(@^P83(LU-&X``&1)BPX/MH&P````2(E-R(B!L0```$B+!>AM``!,BRA-
MA>UT;DR-)1`/``!!#[9$)`%)@\0!A,!T!#P]=>Y-BWT`2(T%\PX``$DIQ$V%
M_W1"36/DNQ````!).=Q)#T;<#Q]$``!(B=I(C37-#@``3(G_Z`["__^%P'4+
M0X`\)ST/A"\"``!-BWT(28/%"$V%_W72,<#HB^W__V1)BP9(B47(2(M]R+D#
M````N@$```!(C35Q#P``Z/G!__](B<-(A<!T*$B+0!!D28L^2(T55P\``$B+
M,.@*PO__2(M#$$B+,/9&#D`/A1H"``!D28L^N0,```"Z`0```$B--2X/``#H
MK\'__TB)1<A(A<`/A*(```!(BP7K;```3(LH387M='%,C26=#0``00^V1"0!
M28/$`83`=`0\/77N38M]`$B-!8`-``!)*<1-A?]T14UCY+L-````23G<20]&
MW`\?A```````2(G:2(TU5PT``$R)_^@.P?__A<!U"T.`/"<]#X1/`0``38M]
M"$F#Q0A-A?]UTDB+!1-M``!(BS!(BT7(2(M`$$B+..A8X___#Q^$``````!D
M28L^N@$```!(C35L#@``Z$O`__]D28L^2(T5<0X``$B)QN@(P?__9$F+!DR-
M-=,,``!-B??&@+$`````2(L%#&P``$R+($V%Y'1?00^V1P%)@\<!A,!T!#P]
M=>])BQPD32GW2(7;=$)-8_]!O0D```!-.>]-#T;O#Q^``````$R)ZDR)]DB)
MW^A"P/__A<!U"T*`/#L]#X2C````28M<)`A)@\0(2(7;==5(BSU&;```2,<%
M,VP```````#H_O+__TB)!2=L``!(B<-(A<`/A(H```"^P`$``$B)W^B^PO__
MC5`!@_H!=@6#^!%U?DB#Q!A;05Q!74%>05]=PV:02XU$)P&`.#$/A=#]__^`
M>`$`#X35_?__Z<']__\/'P!(BT7(9$F+/DN-5"<!2(M`$$B+,.CWO___Z<+^
M__]FD$J-7#L!2(D=I&L``.F$____9$F+/N@FP?__Z=C]__](C3W2#0``,<#H
M<\'__XG!2(L%@FL``$B)VDB-/>`-``!(BS`QP.A6P?__9@\?1```\P\>^E5(
MB>5!5T%6055!5%-(@^P82(L%I&H``$B)?<A,BSA-A?]T7DR-->0+``!-B?5!
M#[9%`4F#Q0&$P'0$/#UU[TF+'TTI]4B%VW0X36/M0;P*````33GE30]&Y6:0
M3(GB3(GV2(G?Z-*^__^%P'4'0H`\*SUT'TF+7PA)@\<(2(7;==I(@\086T%<
M05U!7D%?7<,/'P!"#[94*P&$T@^4P(#Z,`^4P@C0==E(@WW(`'322(M%R(`X
M`'3)2(G'Z,OH__^^+P```$B)QTB)P^B;O___2(U0`4B%P$@/1=I(B=_H^+__
M_[H$````2(TUIPL``$B)Q^A$OO__A<!UADB+?<A(@\086T%<05U!7D%?7>G)
MWO__9@\?A```````\P\>^E6_@````$B)Y>@>OO__9@]O!69*``!(QT`P````
M``\1`&8/;P5C2@``QT!X``````\10!!F#V\%8$H```\10"!=PV8N#Q^$````
M``#S#Q[Z54ACPDB)Y4%728G_059!54R-;SA!5$F)Q%-(@^PH2(EUR$B+=RA(
MBU<PC0S&2#GQ2(E/*$B#T@!(P>@=2`'02(E',$AC1WB%P`^%+0$``$&#_#\/
MCH0```!$B>-,BW7(P>L&C4/_2,'C!HE%Q$P!\TB)1;@/'X0``````/-!#V\&
M3(G_28/&0$$/$44`\T$/;T;000\111#S00]O1N!!#Q%%(/-!#V]&\$$/$44P
MZ/G"__]).=YUQ$B+1;A(BTW(1(MUQ$C!X`9(C40!0$'WWDB)1<A!P>8&1XUD
M-,!)8\1(@_@(<FY(BWW(28UW0$R)Z4B#YOA(BQ=(*?%)B5<X2(M4!_A(*<])
MB50%^$@!R$F)_4B#X/A(@_@(<B!(@^#X,=))BTP5`$B)#!9(@\((2#G"<NX/
M'X0``````$6)9WA(@\0H6T%<05U!7D%?7<,/'T0``*@$=6Q(A<!TWTB+3<@/
MMA%!B%<XJ`)TT`^W5`'^9D&)5`7^Z\,/'P!!OD````!(BW7(28U\!0!!*<9%
M.>9%#T_T26/>2(G:Z-R^__]!BT=X1`'P08E'>(/X0'603(G_2`%=R$4I].CM
MP?__Z8O^__](BTW(BQ%!B5<XBU0!_$&)5`7\Z6#____S#Q[Z54B)Y4%73(U^
M.$%6055!5$F)_%-(B?-(@^P(3(MV*$R+;C!,B?!(P>@#@^`_C4@!QD0&.(!(
M8\%,`?B#^3@/CJ@!``"Z0````"G*=`\QR8G.@\$!Q@0P`#G1<O-(B=_H:,'_
M_V8/[\`/$4,X2<=',`````!!#Q%'$$$/$4<@3(GJ00^VQDV)\$R)]TC!ZAA(
MP>`(3(GI2<'H$$F)T4R)\DC![Q@/MO9,B>I(P>D02`GP00^V\`^VR4C!X`A(
M"?!`#[;W2(G?2,'@"$@)\$$/MO5(P>`(2`GP#[;V00^VT4C!X`A("?!(P>`(
M2`G(2,'@"$@)T$B)0W#HS\#__TB+`TR)YTR)X4R)XDC!Z!A!B`0D2(L#2,'H
M$$&(1"0!2(L#B&<"2(L#08A$)`-(BT,(2,'H&$&(1"0$2(M#"$C!Z!!!B$0D
M!4B+0PB(9P9(BT,(08A$)`=(BT,02,'H&$&(1"0(2(M#$$C!Z!!!B$0D"4B+
M0Q"(80I(BT,008A$)`M(BT,82,'H&$&(1"0,2(M#&$C!Z!!!B$0D#4B+0QB(
M9PY(BT,82(G?08A$)`](BT,@2,'H&$&(1"002(M#($C!Z!!!B$0D$4B+0R"(
M8A)(BT,@08A$)!-(@\0(6T%<05U!7D%?7>FSNO__#Q\`NC@````Q]BG*@_H(
M<RKVP@1U;872#X1W_O__Q@``]L("#X1K_O__,<EFB4P0_NE?_O__#Q]$``")
MT4C'``````!(QT0(^`````!(C4@(2(/A^$@IR`'"@^+X@_H(#X(O_O__@^+X
M,<")QX/`"$B)-#DYT'+SZ1C^__]F#Q]$``#'``````#'1!#\`````.G__?__
M9BX/'X0```````\?`/,/'OI(BPT]90``Z3"Y___S#Q[Z2(/L"$B#Q`C#````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````$``@`E<R\E<P!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`
M26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O<V5L9B]E>&4`+W!R;V,O)6DO
M)7,`4$%27U1%35``+@!005)?4%)/1TY!344`.@`O`%!!4E]'3$]"04Q?1$5"
M54<`4$%27T=,3T)!3%]435!$25(`4$%27T=,3T)!3%]414U0`%!!4E]'3$]"
M04Q?0TQ%04X`4$523#5,24(`4$523$Q)0@!015),-4]05`!015),24\`4$%2
M7TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!005)?1$5"54<`
M4$%27T-!0TA%`%!!4E]435!$25(`,0!L<V5E:R!F86EL960`<F5A9"!F86EL
M960`3$1?3$E"4D%265]0051(`%5315(`4UE35$5-`"]T;7``5$5-4$1)4@!4
M35``55-%4DY!344`)3`R>``E<R5S)7,E<P!P87(M`'!A<FP`+G!A<@!S:&]R
M="!R96%D`"5S)7-C86-H92TE<R5S`"5S)7-T96UP+25U)7,`)7,E<W1E;7`M
M)74M)74E<P`8`'!E<FP`,`!005(Z.E!A8VME<CHZ5D524TE/3@`Q+C`V,P`M
M90`M+0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@
M)7,@9F%I;&5D("AE<G)N;STE:2D*````````)7,Z('!R:79A=&4@<W5B9&ER
M96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T
M<GD@>6]U<B!O<&5R871I;VXI"@```````%5N86)L92!T;R!C<F5A=&4@8V%C
M:&4@9&ER96-T;W)Y```````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C
M86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````
M``!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*
M:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@
M7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D1DE,15]O9F9S971?<VEZ92P@
M)&-A8VAE7VYA;65?<VEZ92D["D)%1TE.('L*)%!!4E]-04=)0R`](")<;E!!
M4BYP;5QN(CL*)$9)3$5?;V9F<V5T7W-I>F4@/2`T.R`@(",@<&%C:R@B3B(I
M"B1C86-H95]N86UE7W-I>F4@/2`T,#L*)%!+6DE07TU!1TE#(#T@(E!+7#`P
M,UPP,#0B.PI]"G-U8B!F:6YD7W!A<E]M86=I8PI["FUY("@D9F@I(#T@0%\[
M"FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D8G5F.PIM>2`D<VEZ
M92`]("US("1F:#L*;7D@)'!O<R`]("@D<VEZ92TQ*2`M("@D<VEZ92TQ*2`E
M("1C:'5N:U]S:7IE.R`@("`@(",@3D]413H@)'!O<R!I<R!A(&UU;'1I<&QE
M(&]F("1C:'5N:U]S:7IE"G=H:6QE("@D<&]S(#X](#`I('L*<V5E:R`D9F@L
M("1P;W,L(#`["G)E860@)&9H+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T
M:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%2
M7TU!1TE#*2D@/CT@,"D@>PIR971U<FX@)'!O<R`K("1I.PI]"B1P;W,@+3T@
M)&-H=6YK7W-I>F4["GT*<F5T=7)N("TQ.PI]"FUY("@D<&%R7W1E;7`L("1P
M<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![(&EF("@D
M14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E
M($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D
M:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S
M*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I;&4Z.D9I
M;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]
M+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E
M;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z
M.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"
M87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*
M54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I;&5N86UE
M.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P
M(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E
M;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@
M"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H;6]D(#`W
M,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D978O;G5L
M;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE9"!B86-K
M9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL96YA;65=
M*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E
M9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET
M7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E<WES
M(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@
M)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC
M>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]
M?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M
M92@I.PIO=71S*'%Q6UPD<')O9VYA;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T
M7W!A<E]T96UP*"D["F]U=',H<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[
M4$%27U1%35!](ETI.PIM>2`H)'-T87)T7W!O<RP@)'-T87)T7V]F7T9)3$5?
M<V5C=&EO;BD["DU!1TE#.B!["FQO8V%L("1324=[7U]705).7U]](#T@<W5B
M('M].PIU;FQE<W,@*&]P96X@7T9(+"`G/#IR87<G+"`D<')O9VYA;64I('L*
M;W5T<RAQ<5M#86XG="!R96%D(&9R;VT@9FEL92`B)'!R;V=N86UE(ETI.R`@
M(R!D;VXG="!U<V4@)"$@:&5R92!A<R!I="!R97%U:7)E<R!%<G)N;RYP;0IL
M87-T($U!1TE#.PI]"FUY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@J
M7T9(*3L*:68@*"1M86=I8U]P;W,@/"`P*2!["F]U=',H<7%;0V%N)W0@9FEN
M9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B(&EN(&9I;&4@(B1P<F]G;F%M
M92)=*3L*;&%S="!-04=)0SL*?0IO=71S*")&;W5N9"!005(@;6%G:6,@870@
M<&]S:71I;VX@)&UA9VEC7W!O<R(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M
M("1&24Q%7V]F9G-E=%]S:7IE("T@;&5N9W1H*")<,$-!0TA%(BDL(#`["G)E
M860@7T9(+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@;F4@
M(EPP0T%#2$4B("8F("1B=68@;F4@(EPP0TQ%04XB*2!["F]U=',H(DYO(&-A
M8VAE(&UA<FME<B!F;W5N9"(I.PIL87-T($U!1TE#.PI]"F]U=',H<7%;0V%C
M:&4@;6%R:V5R("(D8G5F(B!F;W5N9%TI.PIS965K(%]&2"P@)&UA9VEC7W!O
M<R`M("1&24Q%7V]F9G-E=%]S:7IE+"`P.PIR96%D(%]&2"P@)&)U9BP@)$9)
M3$5?;V9F<V5T7W-I>F4["FUY("1O9F9S970@/2!U;G!A8VLH(DXB+"`D8G5F
M*3L*;W5T<R@B3V9F<V5T(&9R;VT@<W1A<G0@;V8@1DE,17,@:7,@)&]F9G-E
M="(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE
M("T@)&]F9G-E="P@,#L*)'-T87)T7V]F7T9)3$5?<V5C=&EO;B`]('1E;&P@
M7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@
M("`@("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%
M(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0[
M"G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN
M86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE
M(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[
M.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]
M("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D
M8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF
M("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L
M*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D
M8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65]
M(#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M
M97T@/2`D9G5L;&YA;64["GT*96QS92!["B1-;V1U;&5#86-H97LD9G5L;&YA
M;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U
M;&QN86UE+`I].PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97TK*SL*?0IR96%D
M(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L
M9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D
M;6]D=6QE.PIM>2`D:6YF;R`]("1-;V1U;&5#86-H97LD;6]D=6QE?3L*<F5T
M=7)N('5N;&5S<R`D:6YF;SL*9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L
M97T["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*
M:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE
M=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`B
M0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I;FUO9&4H*3L*
M)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH,"P@,"D["G)E
M='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D
M:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PHD:6YF;RT^>V9I;&5]
M(#T@)&9I;&5N86UE.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE
M(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL96YA;64B.B`D(5T["G)E='5R
M;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN
M9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E
M<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR
M97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN
M86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N
M86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@
M*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*
M:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N
M86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]
M?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L
M:7-T>R1F:6QE;F%M97T["GT*:68@*"1B=68@;F4@)%!+6DE07TU!1TE#*2![
M"F]U=',H<7%;3F\@>FEP(&9O=6YD(&%F=&5R($9)3$4@<V5C=&EO;B!I;B!F
M:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,@.PI]"B1S=&%R=%]P;W,@
M/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z
M:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L
M("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@
M<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"FEF
M("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G
M("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?
M<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG
M;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP
M72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2
M155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B
M96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'
M5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII
M9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF
M("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@
M)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@
M)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD
M;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@
M)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L
M<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I
M92!Q<5M#86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z("0A73L*?0IE;'-I9B`H
M)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I
M.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[
M)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF
M>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$
M:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@
M0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@
M24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S
M=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF
M("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1P87(@
M;W(@9&EE('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@(B1P87(B.B`D(5T["F)L
M97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE
M=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!
M<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN
M9R!Z:7`@87)C:&EV92`B)'!A<B)=.PI]"FUY("5M971A7W!A<B`](&1O('L*
M:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N
M>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O
M7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*
M?3L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@
M)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A
M73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B=68L(#0["F1I92!Q<5LB)'!A<B(@
M:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F(&5Q("102UI)4%]-04=)
M0SL*8VQO<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)
M3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z
M.D9I;&4Z.D]?4D174B@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP*
M*2!O<B!D:64@<7%;0V%N)W0@8W)E871E(&9I;&4@(B1O=70B.B`D(5T["B1F
M:"T^8FEN;6]D92@I.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<CL*:68@
M*&1E9FEN960@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD@>PIR96%D(%]&2"P@
M)&QO861E<BP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;CL*?2!E;'-E('L*;&]C
M86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM0
M05)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@
M>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"B1F:"T^<')I;G0H
M)&QO861E<BD*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@;&]A9&5R('1O("(D
M;W5T(CH@)"%=.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD[
M"E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*
M<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO
M('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF
M:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N
M9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O
M<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA
M3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L
M:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].R`@("`@("`@(",@
M6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M
M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D9FEL92P@)&YA;64I
M.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1K97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L
M<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>
M7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D
M,2D["FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI
M)'PI('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL
M92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O
M)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T
M.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64["FYE>'0@:68@
M)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F
M:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A
M8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE
M?2`Z("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD
M8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U
M;F1E9CL*;W!E;B!M>2`D=&@L("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#
M86XG="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@/2`\)'1H/CL*8VQO
M<V4@)'1H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N
M="P@(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM005)?5D520D%424U]
M(&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R
M.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@
M)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H
M*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP
M.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L
M96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I"F]R(&1I92!Q<5M%<G)O<B!W
M<FET:6YG(&5M8F5D9&5D($9)3$4@=&\@(B1O=70B.B`D(5T["F]U=',H<7%;
M5W)I='1E;B!A<R`B)&YA;64B72D["GT*?0II9B`H)'II<"D@>PHD>FEP+3YW
M<FET951O1FEL94AA;F1L92@D9F@I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TL*
M;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@>FEP('!A<G0@;V8@(B1O=70B73L*
M?0II9B`H)&UE=&%?<&%R>V-L96%N?2D@>PHD9F@M/G!R:6YT*")<,$-,14%.
M(BD["GT*96QS92!["FEF("@A9&5F:6YE9"`D8V%C:&5?;F%M92D@>PIM>2`D
M8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*<V5E:R`D9F@L(#`L(#`["B1C
M='@M/F%D9&9I;&4H)&9H*3L*<V5E:R`D9F@L(#`L(#(["B1C86-H95]N86UE
M(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H95]N86UE(#T@<W5B<W1R("1C
M86-H95]N86UE+"`P+"`D8V%C:&5?;F%M95]S:7IE.PHD8V%C:&5?;F%M92`N
M/2`B7#`B('@@*"1C86-H95]N86UE7W-I>F4@+2!L96YG=&@@)&-A8VAE7VYA
M;64I.PHD9F@M/G!R:6YT*"1C86-H95]N86UE+`HB7#!#04-(12(I.PI]"FUY
M("1O9F9S970@/2`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BD["B1F:"T^
M<')I;G0H<&%C:R@G3B<L("1O9F9S970I+`HD4$%27TU!1TE#*3L*)&9H+3YC
M;&]S92!O<B!D:64@<7%;17)R;W(@=W)I=&EN9R!T<F%I;&5R(&]F("(D;W5T
M(CH@)"%=.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE
M<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I
M<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q
M=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L90HD
M9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@<7%;9F1O<&5N
M*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US
M(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C
M:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE
M*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z
M.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PIO=71S*")%>'1R86-T:6YG
M('II<"XN+B(I.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H
M;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R
M("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C
M=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE
M>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#
M;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D
M97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C
M+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@
M*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S
M9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S
M:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E
M;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D
M9&5S=%]N86UE(BXN+ETI.PHH)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D
M*"1D97-T7VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE
M('%Q6T5R<F]R(&5X=')A8W1I;F<@>FEP(&UE;6)E<B!T;R`B)&1E<W1?;F%M
M92)=.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B
M.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@
M>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N
M<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R
M;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN
M"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H
M0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR
M97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@
M)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN
M+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H
M*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@
M97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E
M<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T
M<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E
M($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E
M<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U
M:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ
M4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I
M<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP
M<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG
M97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E
M<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I
M<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E
M(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q
M=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*
M979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@
M>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R
M97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L
M('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H
M9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@
M+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M
M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)
M4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D*
M*2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N
M9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D
M<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D
M969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I
M;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U
M<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM5
M4T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0IM>2`D<W1M
M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D
M=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;7D@)&-A8VAE7V1I
M<CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PHD8V%C:&5?9&ER(#T@(G1E;7`M
M)"0B.PI]"F5L<V4@>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE
M(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["FEF("@H
M;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"1F:"DI(#X](#`I('L*
M<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE
M;F=T:"@B7#!#04-(12(I+"`P.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@
M;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS
M965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N
M9W1H*")<,$-!0TA%(BD*+2`D8V%C:&5?;F%M95]S:7IE+"`P.PIR96%D("1F
M:"P@)&)U9BP@)&-A8VAE7VYA;65?<VEZ93L*)&)U9B`]?B!S+UPP+R]G.PHD
M8V%C:&5?9&ER(#T@(F-A8VAE+21B=68B.PI]"GT*8VQO<V4@)&9H.PI]"FEF
M("@A)&-A8VAE7V1I<BD@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PHD14Y6
M>U!!4E]#3$5!3GT@/2`Q.PI]"B1S=&UP9&ER("X]("(D<WES>U]D96QI;7TD
M8V%C:&5?9&ER(CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["B1%3E9[4$%27U1%
M35!](#T@)'-T;7!D:7(["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.
M5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS
M=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@
M0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@
M*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D
M(CL*;7D@)&9H.PHH;W!E;B`D9F@L("<^.G)A=R<L("1T96UP;F%M92D*)B8@
M*'!R:6YT("1F:"`D8V]N=&5N=',I"B8F("AC;&]S92`D9F@I"F]R(&1I92!Q
M<5M%<G)O<B!W<FET:6YG("(D=&5M<&YA;64B.B`D(5T["F-H;6]D("1M;V1E
M+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M
M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@
M)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@
M)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@
M+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`[
M"FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6
M>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N
M86UE+"!R:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI("L@,2D["GT*
M:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D
M<WES>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P
M<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N
M86UE)'-Y<WM?97AE?2(I('L*)'!R;V=N86UE("X]("1S>7-[7V5X97T["G)E
M='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)'-Y<WMP871H
M7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM0
M05)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@
M<R]<421S>7-[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y
M<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L87-T*0II9B`M<R`B
M)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB.PHH*"1P<F]G
M;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF
M("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX
M7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.
M04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`\(#`I
M('L*)'!R;V=N86UE(#T@(BXD<WES>U]D96QI;7TD<')O9VYA;64B.PI]"FUY
M("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H
M*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D
M*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]
M7"Y<+C]<421S>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?9&5L:6U]+SL*)$5.
M5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?
M96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR
M971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*
M9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.
M04U%("D@*2!["F1E;&5T92`D14Y6>R)005)?)%\B?3L*?0IF;W(@*'%W+R!4
M35!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[(E!!4E\D7R)](#T@
M)$5.5GLB4$%27T=,3T)!3%\D7R)](&EF(&5X:7-T<R`D14Y6>R)005)?1TQ/
M0D%,7R1?(GT["GT*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6
M>U!!4E]#3$5!3GT["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970[
M"FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*
M<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF
M:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N
M9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X
M<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*
M<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!
M4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<5MP
M87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO
M('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G;F%M
M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]4
M2U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)2
M3U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/
M4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF
M("0Z.E]?15)23U(["C$["E]?14Y$7U\*``!#04-(10``<&5R;'AS:2YC````
M``````$C16<`````B:O-[P````#^W+J8`````'94,A``````\.'2PP``````
M``````````$;`SL$`0``'P```'!O__\X`0``X'+__V`!``#P<O__>`$``%!V
M__\H!0``8'C__R`!``!0>?__D`$``#"2___``0```)/__^P!```0E/__'`(`
M`)"5__](`@``\)7__V@"``#0EO__E`(``*"9___,`@``T)G__^`"``"PFO__
M"`,``,":__\<`P``@)W__T@#``#`G?__:`,``!"?__^8`P``4*+__\@#```@
MH___^`,``."C__\4!```,*7__SP$``!0I?__7`0``&"F__^,!```T+#__\0$
M```PM/__]`0``%"U__]0!0``H+7__W`%``"`M___H`4``!"Z___0!0``````
M`!0``````````7I2``%X$`$;#`<(D`$``!0````<````.'?__R8`````1`<0
M`````"0````T````,&[__W`#````#A!&#AA*#PMW"(``/QHY*C,D(@`````4
M````7````'AQ__\0```````````````4````=````'!Q__]@`P``````````
M```L````C````+AW___3&````$$.$(8"0PT&28\#C@2-!8P&@P<#P!@*#`<(
M00L````H````O````&B0___+`````$$.$(8"0PT&38\#C@2-!8P&@P<"=@H,
M!PA)"RP```#H````#)'__P0!````00X0A@)##09(CP..!(T%C`9(@P<"@0H,
M!PA+"P```"@````8`0``[)'__W0!````00X0A@)##090CP..!(T%C`:#!P)`
M"@P'"$0+'````$0!``!`D___6P````!%#A"&`E$-!D6#`W@,!P@H````9`$`
M`("3___8`````$$.$(8"0PT&5XX#C02,!8,&`GP*#`<(00L``#0```"0`0``
M-)3__\4"````00X0A@)##09&CP..!(T%18P&2(,'`PD""@P'"$@+=PH,!PA!
M"P``$````,@!``#,EO__*0`````````D````W`$``.B6___=`````$4.$(8"
M0PT&88T#C`2#!0*N"@P'"$$+$`````0"``"@E___"0`````````H````&`(`
M`)R7__^V`@```$4.$(8"0PT&7(\#C@2-!8P&@P<"Z0H,!PA#"QP```!$`@``
M,)K__S(`````10X0A@)(#09!@P-?#`<(+````&0"``!0FO__00$```!%#A"&
M`D,-!E.,`X,$`M\*#`<(1@MA"@P'"$\+````+````)0"``!PF___/@,```!%
M#A"&`DP-!DV/`XX$C06,!H,'`XL""@P'"$<+````+````,0"``"`GO__R```
M``!%#A"&`D,-!DV/`XX$C06,!H,'`H(*#`<(20MG#`<(&````/0"```@G___
MP`````!%#A"&`D,-!@```"0````0`P``Q)___T8!````00X0A@)##09BC0.,
M!(,%`MT*#`<(10L<````.`,``.R@__\>`````$4.$(8"0PT&50P'"````"P`
M``!8`P``[*#__P@!````10X0A@)##09(CP..!(T%C`9/@P<"?@H,!PA+"P``
M`#0```"(`P``S*'__VT*````10X0A@)##090CP..!(T%C`:#!P,!!`H,!PA'
M"P+""@P'"$4+````+````,`#```$K/__6@,```!%#A"&`D,-!DV/`XX$C06,
M!H,'`[@""@P'"$,+````,````/`#```TK___%P$```!%#A"&`D,-!DV/`XX$
MC06,!H,'`G\*#`<(1`L">@P'"````"0````D!```(''__PX"````10X0A@)#
M#09'C`.#!`-J`0H,!PA!"P`<````3`0``/BO__]&`````$4.$(8"2`T&>`P'
M"````"P```!L!```*+#__^`!````10X0A@)&#09"CP-'C@2-!4:,!DB#!P,P
M`0H,!PA&"RP```"<!```V+'__X,"````10X0A@)##09"CP-*C@2-!8P&1(,'
M`]`!"@P'"$@+`!````#,!```.+3__Q````````````````0````0`````0``
M`$=.50```````P````(`````````!````&````!^&O[*1D1/`'LB='EP92(Z
M(F1E8B(L(F]S(CHB=6)U;G1U(BPB;F%M92(Z(F=L:6)C(BPB=F5R<VEO;B(Z
M(C(N-#$M,75B=6YT=3$B+")A<F-H:71E8W1U<F4B.B)A;60V-")]``````0`
M``!L````?AK^RD9$3P![(G1Y<&4B.B)D96(B+")O<R(Z(G5B=6YT=2(L(FYA
M;64B.B)L:6)P87(M<&%C:V5R+7!E<FPB+")V97)S:6]N(CHB,2XP-C,M,6)U
M:6QD,B(L(F%R8VAI=&5C='5R92(Z(F%M9#8T(GT`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````\"D```````"P*0``
M`````%-Q````````CG````````"@<`````````$`````````Z`(````````!
M`````````/@"````````#```````````(`````````T`````````T&H`````
M```9`````````+#+````````&P`````````(`````````!H`````````N,L`
M```````<``````````@`````````]?[_;P````#``P````````4`````````
M<`T````````&`````````*`$````````"@````````"!!`````````L`````
M````&``````````5`````````````````````P````````#8S0````````(`
M````````$`4````````4``````````<`````````%P````````#X%```````
M``<`````````,!,````````(`````````,@!````````"0`````````8````
M`````!X`````````"`````````#[__]O``````$```@`````_O__;P````"P
M$@```````/___V\``````0````````#P__]O`````/(1````````^?__;P``
M```'````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MV,L`````````````````````````````,"````````!`(````````%`@````
M````8"````````!P(````````(`@````````D"````````"@(````````+`@
M````````P"````````#0(````````.`@````````\"``````````(0``````
M`!`A````````("$````````P(0```````$`A````````4"$```````!@(0``
M`````'`A````````@"$```````"0(0```````*`A````````L"$```````#`
M(0```````-`A````````X"$```````#P(0`````````B````````$"(`````
M```@(@```````#`B````````0"(```````!0(@```````&`B````````<"(`
M``````"`(@```````)`B````````H"(```````"P(@```````,`B````````
MT"(```````#@(@```````/`B`````````",````````0(P```````"`C````
M````,",```````!`(P```````%`C````````8",```````!P(P```````(`C
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````(T`````````I005(N<&T*``````````#X
M<@```````$=#0SH@*%5B=6YT=2`Q-"XR+C`M,3=U8G5N='4S*2`Q-"XR+C``
M`"YS:'-T<G1A8@`N;F]T92YG;G4N<')O<&5R='D`+FYO=&4N9VYU+F)U:6QD
M+6ED`"YI;G1E<G``+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E
M<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI
M=``N<&QT+F=O=``N<&QT+G-E8P`N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F
M<F%M95]H9'(`+F5H7V9R86UE`"YN;W1E+D%"22UT86<`+FYO=&4N<&%C:V%G
M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9&%T82YR96PN<F\`+F1Y;F%M
M:6,`+F1A=&$`+F)S<P`N8V]M;65N=```````````````````````````````
M````````````````````````````````````````````````````````````
M```+````!P````(`````````4`,```````!0`P```````#``````````````
M```````(````````````````````'@````<````"`````````(`#````````
M@`,````````D````````````````````!````````````````````#$````!
M`````@````````"D`P```````*0#````````'`````````````````````$`
M```````````````````Y````]O__;P(`````````P`,```````#``P``````
M`.``````````!0`````````(````````````````````0P````L````"````
M`````*`$````````H`0```````#0"`````````8````!````"``````````8
M`````````$L````#`````@````````!P#0```````'`-````````@00`````
M``````````````$```````````````````!3````____;P(`````````\A$`
M``````#R$0```````+P`````````!0`````````"``````````(`````````
M8````/[__V\"`````````+`2````````L!(```````"```````````8````!
M````"````````````````````&\````$`````@`````````P$P```````#`3
M````````R`$````````%``````````@`````````&`````````!Y````!```
M`$(`````````^!0```````#X%````````!`%````````!0```!H````(````
M`````!@`````````@P````$````&```````````@`````````"`````````;
M````````````````````!````````````````````'X````!````!@``````
M```@(````````"`@````````<`,``````````````````!``````````$```
M``````")`````0````8`````````D",```````"0(P```````!``````````
M```````````0`````````!``````````D@````$````&`````````*`C````
M````H",```````!@`P``````````````````$``````````0`````````)L`
M```!````!@``````````)P`````````G````````T$,`````````````````
M`"````````````````````"A`````0````8`````````T&H```````#0:@``
M``````T````````````````````$````````````````````IP````$````"
M``````````!P`````````'````````"P0```````````````````$```````
M`````````````*\````!`````@````````"PL````````+"P````````!`$`
M``````````````````0```````````````````"]`````0````(`````````
MN+$```````"XL0```````.`$```````````````````(````````````````
M````QP````<````"`````````)BV````````F+8````````@````````````
M````````!````````````````````-4````'`````@````````"XM@``````
M`+BV````````[`````````````````````0```````````````````#C````
M#@````,`````````L,L```````"PNP````````@````````````````````(
M``````````@`````````[P````\````#`````````+C+````````N+L`````
M```(````````````````````"``````````(`````````/L````!`````P``
M``````#`RP```````,"[````````&`````````````````````@`````````
M```````````(`0``!@````,`````````V,L```````#8NP`````````"````
M````!@`````````(`````````!``````````C0````$````#`````````-C-
M````````V+T````````H`@``````````````````"``````````(````````
M`!$!```!`````P``````````T`````````#`````````*```````````````
M``````@````````````````````7`0``"`````,`````````*-`````````H
MP````````"@````````````````````(````````````````````'`$```$`
M```P````````````````````*,`````````F`````````````````````0``
M```````!``````````$````#`````````````````````````$[`````````
@)0$```````````````````$`````````````````````
